@@ -3,8 +3,12 @@ deflang = 'en'
 lang = None
 
 if os.name == 'posix':
-    locale.setlocale(locale.LC_ALL,'')
-    loc, enc = locale.getlocale()
+    try:
+        locale.setlocale(locale.LC_ALL,'')
+    except:
+        loc,enc = locale.getdefaultlocale()
+    else:
+        loc, enc = locale.getlocale()
 
 # Windows locales are named differently, e.g. German_Austria instead of de_AT
 # Fortunately, we can find the POSIX-like type using a different method.
@@ -85,3 +89,19 @@ for group,v in lang.UNIT_GROUPS.items():
     for u,rng in v:
         lang.unit_group_lookup[u] = group,n
         n += 1
+
+WORD_TO_SING_PLUR_PAIR = {}
+if hasattr(lang,'PLURALS'):
+    for forms in lang.PLURALS:
+        for f in forms:
+            WORD_TO_SING_PLUR_PAIR[f] = forms
+
+def get_pluralized_form (word, n):
+    from gettext import ngettext
+    if WORD_TO_SING_PLUR_PAIR.has_key(word):
+        forms = list(WORD_TO_SING_PLUR_PAIR[word])
+        forms += [n]
+        return ngettext(*forms)
+    else:
+        return word
+
