@@ -18,39 +18,39 @@ fields={'cuisine': ['English','Scottish','Welsh','Irish','American',
                   }
 
 SYNONYMS=[
-    # the first item of each list is the 
+    # the first item of each list is the
     ["aubergine","eggplant"],
-    ["spring onion","scallion","green onion"],
-    ["rocket","arugula"],
     ["azuki beans", "adzuki beans", "adzuki", "azuki"],
-    ["mangetout","snap peas"],
-    ["chinese leaves","bok choy"],
-    ["capsicum","chilli pepper"],
-    ["maise","sweetcorn","corn","sweet corn"],
-    ["red bell pepper","red pepper"],
-    ["green pepper", "bell pepper","green bell pepper", "pepper"],
     ["beet","beetroot"],
-    ["spring greens","collard greens"],
-    ["coriander","cilantro"],
-    ["turabaga","swede"],
-    ["courgette","zucchini"],
-    ["chokeberry","cooking apple"],
-    ["juneberry","saskatoon"],
-    ["nannyberry","sheepberry"],
+    ["capsicum","chilli pepper"],
     ["chinese gooseberry","kiwi fruit","kiwi"],
-    ["sunberry","wonderberry"],
-    ["start fruit","carambola"],
+    ["chinese leaves","bok choy"],
+    ["chokeberry","cooking apple"],
+    ["coriander","cilantro"],
+    ["courgette","zucchini"],
     ["dragonfruit" , "pitaya"],
+    ["green pepper", "bell pepper","green bell pepper", "pepper"],
     ["jackfruit","nangka"],
+    ["juneberry","saskatoon"],
     ["langsat","longkong", "duku"],
-    ["velvet persimmon","mabolo"],
+    ["maise","sweetcorn","corn","sweet corn"],
     ["mamoncillo", "quenepa", "genip"],
+    ["mangetout","snap peas"],
+    ["nannyberry","sheepberry"],
+    ["red bell pepper","red pepper"],
+    ["rocket","arugula"],
     ["rose apple", "malay apple"],
     ["salak", "snakefruit"],
     ["sapodilla", "chiku", "sapadilla", "snake fruit", "sawo"],
     ["soursop", "guanabana"],
-    ['black cod','sablefish'],
-    ['patagonian toothfish','chilean sea bass'],
+    ["spring greens","collard greens"],
+    ["spring onion","scallion","green onion"],
+    ["start fruit","carambola"],
+    ["sunberry","wonderberry"],
+    ["swede","rutubaga"],
+    ["velvet persimmon","mabolo"],
+    ["black cod","sablefish"],
+    ["patagonian toothfish","chilean sea bass"],
     ]
 
 # a dictionary key=ambiguous word, value=list of terms
@@ -556,40 +556,42 @@ DENSITY_TABLE={
     "sugar, confectioners": 0.6
             }
 
-UNITS = [["bucket" , ["bucket", "buckets", "bckt."]],
-         ["peck", ["peck", "pecks"]],
-         ["bushel", ["bushel", "bushels", "bsh.", "bu.", "bu", "bsh", "bshl", "bshl."]],
-         ["grains", ["grain", "grains"]],
-         ["dram", ["dram", "drams"]],
-         ["drop",["drop"]],
-         ["tsp", ["teaspoon","tsp", "tsp.","tea spoon", "tsps.", "teaspoons", "tea spoons", "Teaspoon", "t"]],
-         ["Tbs", ["tablespoon","tbs", "tbsp", "tbs.", "tbsp.", "table spoon", "tbsps.", "tablespoons", "Tablespoon", "T"]],
-         ["lb", [ "pound", "lb","lb.", "lbs.", "pounds"]],
-         ["oz", [ "ounce", "oz","ounces", "oz."]],
-         ["c", ["cup", "c.", "cups"]],
-         ["qt", ["quart", "qt.", "quarts"]],
-         ["pt", ["pint", "pt.", "pints"]],
-         ["gallon", ["gallon", "gallons","gal."]],
-         ["ml", ["mililiter","ml", "ml.","mililiters"]],
-         ["cl", ["centiliter","cl", "cl.", "centiliters"]],
-         ["dl", ["deciliter","dl", "dl.","deciliters"]],
-         ["l", ["liter", "l.", "lit.", "liters"]],
-         ["g", ["grams", "gram", "g."]],
-         ["mg", ["miligram", "mg.", "mg", "miligrams"]],
-         ["kg", ["kilogram","kg.", "kg",  "kilograms"]],
-         ['fl. oz.',['fluid ounce','fluid ounces','fl. ounce','fl. ounces',
-                     'fl, oz','fl, oz.','fl. oz.']],
-         # These names aren't really convertible, but we want them to
-         # be recognized as units...
-         ['small',['small','sm','Small','sm.']],         
-         ['medium',['medium','med.','Medium']],
-         ['large',['large','Large','lg','lg.']],
-         ['clove',['clove','cloves','clv.']],
-         ['whole',['whole','wh.','whl']],
-         ['package',['pkg.','pkg','package','Pkg.','Package','pack']],
-         ['box',['Box','box','bx']],
-         ['can',['can','Can','cn','cn.']],
-         ['head',['head','Head','hd','hd.']],
+UNITS = [["",       ["each",   "eaches",  "ea",   "ea."]],
+         ["bucket", ["bucket", "buckets", "bckt", "bckt."]],
+         ["peck",   ["peck",   "pecks"]],
+         ["bushel", ["bushel", "bushels", "bshl", "bshl.", "bsh", "bsh.", "bu", "bu."]],
+         ["grains", ["grain",  "grains"]],
+         ["dram",   ["dram",   "drams"]],
+         ["drop",   ["drop",   "drops"]],
+         ["fl oz",  ["fl oz",      "fluid ounce","fluid ounces","fl ounces",   "fl. ounces","fl. oz",     "fl oz.",     "fl. oz."]],
+         ["tsp",    ["teaspoon",   "teaspoons",  "tea_spoon",   "tea_spoons",  "Teaspoon",  "Teaspoons",  "Tea_spoon",  "Tea_spoons",  "tsps","tsps.","Tsps","Tsps.","tsp","tsp.","Tsp","Tsp.","ts","ts.","Ts","Ts.","t","t."]],
+         ["Tbs",    ["tablespoon", "tablespoons","table_spoon", "table_spoons","Tablespoon","Tablespoons","Table_spoon","Table_spoons","tbsp","tbsp.","Tbsp","Tbsp.","tbs","tbs.","Tbs","Tbs.","tb","tb.","Tb","Tb.","T","T."]],
+         ["lb",     ["pound",      "pounds",     "lbs",  "lbs.",  "lb",  "lb."]],
+         ["oz",     ["ounce",      "ounces",     "oz",   "oz."]],
+         ["c",      ["cup",        "cups",       "c."]],
+         ["qt",     ["quart",      "quarts",     "qt.",  "Qt", "Qt."]],
+         ["pt",     ["pint",       "pints",      "pt.",  "Pt", "Pt."]],
+         ["gallon", ["gallon",     "gallons",    "gal",  "gal."]],
+         ["ml",     ["mililiter",  "mililiters", "ml",   "ml."]],
+         ["cl",     ["centiliter", "centiliters","cl",   "cl."]],
+         ["dl",     ["deciliter",  "deciliters", "dl",   "dl."]],
+         ["l",      ["liter",      "liters",     "lit.", "l", "l."]],
+         ["g",      ["grams",    "gram",      "g.", "g", "gr", "gr."]],
+         ["mg",     ["miligram", "miligrams", "mg", "mg."]],
+         ["kg",     ["kilogram", "kilograms", "kg", "kg."]],
+         # These names aren"t really convertible, but we want them to
+         # be recognized as units.
+         ["small",  ["small",  "Small",    "sm",  "sm."]],
+         ["medium", ["medium", "Medium",   "med", "med.", "Med", "Med."]],
+         ["large",  ["large",  "Large",    "lg",  "lg.",  "Lg",  "Lg."]],
+         ["box",    ["box",    "Box",      "bx"]],
+         ["whole",  ["whole",  "whl",      "wh."]],
+         ["clove",  ["clove",  "cloves",   "clv",    "clv."]],
+         ["can",    ["can",    "Can",      "cn",      "cn."]],
+         ["head",   ["head",   "heads",    "Head",    "Heads",    "hd",       "hd."]],
+         ["package",["pkg.",   "package",  "Package", "packages", "Packages", "pkg", "Pkg.", "pack"]],
+         ["slice",  ["slice",  "slices"]],
+         ["bunch",  ["bunch",  "bunches"]],
          ]
 
 METRIC_RANGE = (1,999)
@@ -645,9 +647,9 @@ VOL_TO_MASS_TABLE = {
     ("cl", "kg"): 0.01,
     ("cl", "g") : 10,
     ("dl", "kg") : 0.1,
-    ("dl", "g") : 100,    
+    ("dl", "g") : 100,
     ("l", "kg") : 1}
-    
+
 def add_itm (kd, k, v):
     if kd.has_key(k):
         kd[k].append(v)
