@@ -43,8 +43,8 @@ class LinkedPangoBuffer (PangoBuffer):
                 href = m.groups()[0]
                 body = m.groups()[1]
                 if self.markup_dict.has_key(body) and self.markup_dict[body]!=href:
-                    raise """Damn -- our not-so-clever implementation of <a href=""> parsing requires
-                    that no two distinct links have the same text describing them!"""
+                    raise Exception("""Damn -- our not-so-clever implementation of <a href=""> parsing requires
+                    that no two distinct links have the same text describing them!""")
                 self.markup_dict[body]=href
                 m = self.href_regexp.search(txt,m.end())
             txt = self.href_regexp.sub(r'<span %s>\2</span>'%self.url_markup,txt)
