@@ -477,7 +477,7 @@ class RatingConverter:
 
     def add (self, id, rating):
         if type(rating)==int:
-            raise "Why do you need me? id: %(id)s rating: %(rating)s"%locals()
+            raise Exception("Why do you need me? id: %(id)s rating: %(rating)s" % locals())
         self.to_convert[id]=rating
 
     def get_conversions (self, star_generator=None):
