@@ -1,6 +1,7 @@
 import about_dot_com_plugin
 import foodnetwork_plugin
-
+import allrecipes_plugin
 plugins = [about_dot_com_plugin.AboutDotComPlugin,
            foodnetwork_plugin.FoodNetworkPlugin,
+           allrecipes_plugin.AllRecipesPlugin
            ]
