@@ -1,5 +1,5 @@
 import gourmet.convert as convert
-import gtk, gtk.glade
+import gtk
 from gourmet.gglobals import *
 from gourmet.gdebug import *
 from gourmet.gtk_extras.cb_extras import *
@@ -20,7 +20,8 @@ class ConvGui:
                   okcb=None
                   ):
         self.possible_conversions = None
-        self.glade = gtk.glade.XML(os.path.join(current_path,'converter.glade'))
+        self.ui = gtk.Builder()
+        self.ui.add_from_file(os.path.join(current_path,'converter.ui'))
         self.conv = converter
         self.changing_item = False
         self.okcb = okcb
@@ -28,7 +29,7 @@ class ConvGui:
                    'itemComboBox', 'densitySpinButton', 'useDensityCheckButton', 'statusbar','expander1','messageLabel']
         # grab all our widgets
         for w in self.widget_names:
-            setattr(self,w,self.glade.get_widget(w))
+            setattr(self,w,self.ui.get_object(w))
         # HACK FOR READABILITY w/o glade change
         self.resultLabel = self.amt2Label
         self.resultLabel.set_use_markup(True)
@@ -57,7 +58,7 @@ class ConvGui:
         setup_typeahead(self.itemComboBox)
         if amt1:
             self.amt1Entry=self.conv.float_to_frac(amt1)
-        self.glade.signal_autoconnect({
+        self.ui.connect_signals({
             'amt1changed':self.changed,
             'unit1changed':self.changed,
             'unit2changed':self.changed,
